/*******************************************************
 THIS COMMAND FILE SHOWS EXAMPLES OF HOW TO USE
 ARRAYS IN A SAS DATA STEP

 FILENAME: array.sas
********************************************************/
title;
options pageno=1;

/*SET UP MISSING VALUES WITH ARRAYS*/

data owen;
  infile "owen.dat";
  input fam_num childnum age sex race w_rank income_c height weight 
  hemo vit_c vit_a head_cir fatfold b_weight mot_age b_order
  m_height f_height ;

  /*SET UP MISSING VALUE CODES USING ARRAYS*/

  array mis99(5) vit_a head_cir fatfold mot_age b_order;
  array mis999(3) b_weight m_height f_height;
   
  do i=1 to 5;
    if mis99(i) = 99 then mis99(i)=. ;
  end;
  do i=1 to 3;
    if mis999(i) = 999 then mis999(i)=. ;
  end;

  drop i;
run;
proc means data=owen;
run;

/*CREATE NEW VARIABLES USING ARRAYS*/

data owen2;
  set owen;
  array origvar(3) head_cir fatfold b_weight;
  array logvar (3) lhead lfatfold lbwt;

  do i=1 to 3;
    logvar(i)=log(origvar(i));
  end;
  drop i;
run;

proc means data=owen2;
var head_cir fatfold b_weight lhead lfatfold lbwt;
run;

/*SET UP DUMMY VARIABLE USING ARRAYS*/

data owen3;
  set owen;
 if mot_age not=. then do;
     if mot_age < 20 then agegrp = 1;
     if mot_age  >=   20 and mot_age  < 25 then agegrp = 2;
     if mot_age  >=   25 and mot_age  < 30 then agegrp = 3;
     if mot_age  >=   30 and mot_age  < 35 then agegrp = 4;
     if mot_age  >=   35 and mot_age  < 40 then agegrp = 5;
     if mot_age  >=   40 then agegrp  = 6;
  end;

if agegrp not=.   then do;
  array dumvar(6) agedum1 - agedum6;
    do i = 1 to 6;
	  dumvar(i)= (agegrp=i);
	end;
end;
drop i;
run;

proc print data=owen3(firstobs=71 obs=95);
  var mot_age agegrp agedum1-agedum6;
  title;
run;
proc means data=owen3;
run;



/*ARRAYS FOR CHARACTER VARIABLES*/

data demo;
   length lname $12;
   input lname $ school $ teacher $ section $
         gender $ age weight sbp symptm1 symptm2 symptm3;

   array charvar(4) $ school teacher section gender ;
     do i = 1 to 4;
     if charvar(i) = "NA" then charvar(i) = " ";
     end;
   drop i;
cards;
Timmer   Gregory  Smith    A  Female  14 122 132   2   1  88
Johnson  Gregory  Smith    A  Male    13 128 999   1  99  99
Miller   Gregory  Smith    A  NA      88 135 112   2   1   3
Gravlin  Gregory  Smith    A  Female  14  99 115  88  88  88
James    Gregory  Rorrach  B  Female  13 999  95   1   3   2
Kincaid  Gregory  Rorrach  B  Male    14 136 108   1   2  88
Branson  Gregory  Rorrach  B  Male    99 127 999   3  99  99
Bidwell  NA       NA      NA  Male    12 103 100   2   3  99
O'Hara   Lincoln  Marston  A  Male    14 139 117   1  99  99
Petrovic Lincoln  Marston  A  Female  13 128 107   2   1   3
Jackson  Lincoln  Marston  A  Female  14 103  98  99  99  99
;
proc format;
  value symptmfmt 1="Fever" 2="Headache" 3="Rash" 88-99=" ";
run;
proc datasets lib=work;
  modify demo;
  format symptm1 symptm2 symptm3 symptmfmt.;
run; quit;
proc print data=demo;
run;

/*A MORE COMPLICATED DUMMY VARIABLE SETUP*/

data demo2;
   set demo;

   array symptom(*) symptm1-symptm3;
     do i = 1 to 3;
       if symptom(i) = 1 then fever=1;
       if symptom(i) = 2 then headache=1;
       if symptom(i) = 3 then rash=1;
     end;

   /*Substitute zero for missing values in the
	 new variables*/

   array fhr (3) fever headache rash;
     do i = 1 to 3;
       if fhr (i) = . then fhr (i) = 0;
     end;

   totsymp = sum (fever, headache, rash);
   drop i;
run;

proc print data=demo2;
  title "Demo Data After Manipulation";
run;

/**********************************************************
 MULTIDIMENSIONAL ARRAY EXAMPLE
***********************************************************/

data test;
  input subject
        test1q1 test1q2 test1q3 test1q4 test1q5
        test2q1 test2q2 test2q3 test2q4 test2q5
		test3q1 test3q2 test3q3 test3q4 test3q5;
  cards;
100  4 5 3 1 2 1 5 3 3 4 2 4 3 3 99
200  2 2 3 2 1 1 99 1 3 4 1 5 4 1 4
300  5 4 3 3 4 5 2 1 1 1 1 1 4 1 1
400  1 2 3 3 1 3 1 2 2 1 3 3 2 4 5
500  1 1 1 1 99 2 1 4 99 5 5 4 2 1 1
;
proc print data=test;
title "Test: Listing of Original Data Set";
run;

/*Rearrange data into Long format*/

data test2(keep=subject test question response);
  set test;

  array t(3,5) test1q1-test1q5
                  test2q1-test2q5
				  test3q1-test3q5;

  do i=1 to 3;
    do j=1 to 5;
	  test=i;
      question=j;
	  response=(t(i,j));
	  output;
	end;
  end;
run;

proc print;
 title "Test2: Rearranged Data";
run;

/*Use variables TEST and QUESTION as array indices
  and fix missing values*/

data test3(keep=subject test question response);
  set test;
  array t(3,5) test1q1-test1q5
               test2q1-test2q5
			   test3q1-test3q5;
  do test=1 to 3;
    do question=1 to 5;
	   if t(test,question)=99 then t(test,question)=.;
	   response=(t(test,question));
	  output;
	end;
  end;
run;

proc print data=test3;
 title "Test3: 99 Replaced with '.'";
run;

/*Only write out Observations with Non-Missing Values*/

data test4(keep=subject test question response);
  set test;
  array t(3,5) test1q1-test1q5
                  test2q1-test2q5
				  test3q1-test3q5; 
  do test=1 to 3;
    do question=1 to 5;
	   if t(test,question) not=99 then do;
          response=(t(test,question));
	      output;
	   end;
	end;
  end;
run;

proc print data=test4;
 title "Test4: Only Non-Missing Values Written to New Data Set";
run;


/************** ARRAY SUBSCRIPT OUT OF RANGE ERROR ****************/

data owen3;
  infile "owen.dat";
  input fam_num childnum age sex race w_rank income_c height weight 
  hemo vit_c vit_a head_cir fatfold b_weight mot_age b_order
  m_height f_height ;

  /*SET UP MISSING VALUE CODES USING ITERATIVE DO STATEMENTS*/

  array mis99(5) vit_a head_cir fatfold mot_age b_order;
   
  do i=1 to 6;
    if mis99(i) = 99 then mis99(i)=. ;
  end;
  
  drop i;
run;

