/************************************************
 THIS COMMAND FILE ILLUSTRATES HOW TO RECODE 
  NUMERIC VARIABLES INTO CHARACTER VARIABLES
  AND VICE VERSA.

 FILENAME: CHAR2NUM.SAS
*************************************************/

title;
options pageno=1 nodate;

/*RECODE CHARACTER VALUES TO NUMERIC*/
data hosp;
  input hospital $ @@;
  cards;
1 2 81 99 100 101 102 103 104 105 
;

data hospital2;
  set hosp;
  nhosp  = hospital*1;
  nhosp2 = input(hospital,3.); 
run;

proc print data=hospital2;
run;
proc contents data=hospital2;
run; 

/*REPLACE THE CHARACTER VARIABLE WITH A NUMERIC VARIABLE
  HAVING THE SAME NAME*/
data hospital3;
  set hosp;
  N_hosp = hospital*1;
  drop hospital;
  rename N_hosp = hospital;
run;
proc print data=hospital3;
run;
proc contents data=hospital3;
run;


/*RECODE NUMERIC TO CHARACTER*/
data temp;
  input age @@;
  agechar  = put(age,$2.);
  agechar2 = compress(put(age,$2.));
  cards;
1 2 4 7 9 10 11 15 22 23 35
;
proc print;
run;
proc contents data=temp;
run;

proc sort data=temp;
by agechar2;
run;
proc print data=temp;
title "Sorted by AgeChar2";
run;


/*RECODE NUMERIC TO CHARACTER AND PUT ZEROES AT THE BEGINNING
  OF THE NUMERIC VALUE*/
title;
data FIXID;
	input HHID PERSON;
	CHHID=put(HHID,z6.0);  
	attrib CHHID label='HOUSEHOLD IDENTIFIER' length=$6 format=$char6.;
	drop HHID;                                 
	rename CHHID=HHID; 
cards;          
1       1         
2       1         
3       1         
3       2         
10	    1         
10001   1         
10003   2         
10003   3         
10004   10        
10004   4         
10013   4         
10038   10        
;
proc print;
var hhid person;
run;
proc contents;
run;

/*DISPLAY NUMERIC VARIABLES WITH LEADING ZEROES*/
data addzeroes;
  input HHID PERSON;  
  format hhid z6.0 person z2.0;
cards;          
1       1         
2       1         
3       1         
3       2         
10	    1         
10001   1         
10003   2         
10003   3         
10004   10        
10004   4         
10013   4         
10038   10        
;
proc print;
run;
proc contents;
run;
