/********************************************
 THIS COMMAND FILE SHOWS EXAMPLES OF USING
 PROC COMPARE FOR COMPARING THE VALUES IN
 TWO SAS DATASETS.

 FILENAME: COMPARE.SAS
*********************************************/
options nodate pageno=1;
title;

/**********************************************
 CREATE DATA TO USE IN EXAMPLES
***********************************************/
data pulse;
   infile "pulse.dat";
   input pulse1 pulse2 ran smokes sex height weight activity;
   id = _n_;
   label pulse1="Pulse at Time 1"
         pulse2="Pulse at Time 2"
         ran   ="Ran in Place?"
         height="Height(inches)"
         weight="Weight(pounds)"
         activity="Activity Level";
run;

/*copy the data set to a new data set and modify it*/
data pulse2;
  set pulse;
  htcm = height/.3937;
  wtkg = weight/2.2;
  bmi = wtkg/(htcm/100)**2;
  if _n_<=10 then ran=ran+ranuni(12);
  if _n_=92  then delete;
run;

/*compare the two data sets*/
proc sort data=pulse; by id; run;
proc sort data=pulse2; by id;run;
proc compare base=pulse compare=pulse2 listall;
 id id;
run;

/*compare the two data sets and create a new data set
  that contains the DIFFERENCES for each observation*/
proc compare base=pulse compare=pulse2 listall out=newdata ;
  id id;
run;
proc print data=newdata(obs=10);
run;

/*compare the two data sets and create a new data set
  that contains 4 observations for each original case,
  the base values, compare values, dif, and percent difference*/
proc compare base=pulse compare=pulse2 listall out=newdata2 outall ;
  id id;
run;
proc print data=newdata2(obs=12);
run;

