/********************************************
 THIS COMMAND FILE SHOWS EXAMPLES OF USING
 PROC DATASETS FOR MANAGING FILES AND
 LIBRARIES IN SAS.

 FILENAME: DATASETS.SAS
*********************************************/
options nodate pageno=1;
title;
proc options;
run;


/**********************************************
 CREATE DATA TO USE IN EXAMPLES
***********************************************/
data pulse;
   infile "pulse.dat";
   input pulse1 pulse2 ran smokes sex height weight activity;
   label pulse1="Pulse at Time 1"
         pulse2="Pulse at Time 2"
         ran   ="Ran in Place?"
         height="Height(inches)"
         weight="Weight(pounds)"
         activity="Activity Level";
run;

data males females missingsex;
  set pulse;
  if sex=1 then output males;
  if sex=2 then output females;
  if sex = . then output missingsex;

run;

/****************************************************
 APPEND TWO DATASETS
****************************************************/
proc datasets ;
  append base=males data=females;
  run;
  delete females;
  run;
  change males=alldata;
run;quit;

/****************************************************
 CHANGE THE NAME OF A DATASET
****************************************************/
proc datasets lib=work;
  change pulse=heartrate;
run;quit;

/****************************************************
 GET CONTENTS OF A DATASET
****************************************************/
proc datasets lib=work;
  contents data=heartrate;
run;quit;

/****************************************************
 COPY DATASETS FROM ONE LIBRARY TO ANOTHER
****************************************************/
libname sasdata1 v6 "c:\documents and settings\cscar\desktop\sasdata1";
libname sasdata2 v9 "c:\documents and settings\cscar\desktop\sasdata2";

proc datasets ;
  copy in=sasdata1 out=sasdata2;
run;quit;

/*****************************************************
 SPECIFY A LIBRARY IN THE PROC STATEMENT
******************************************************/


proc datasets lib=sasdata2;
  copy in=sasdata1 out=sasdata2;
run; quit;

/*****************************************************
 TO RESTRICT THE COPYING TO DATASETS ONLY,
  USE MEMTYPE=DATA
 (EXCLUDE FORMATS CATALOGS)
******************************************************/

proc datasets memtype=data lib=sasdata2;
  copy in=sasdata1 out=sasdata2;
run;quit;

/*****************************************************
 TO COPY ONLY SELECTED DATA SETS, USE A 
  SELECT STATEMENT.
******************************************************/


proc datasets lib=sasdata2;
  copy in=work out=sasdata2;
  select heartrate; 
run;quit;

/****************************************************
 DELETE DATASETS FROM A LIBRARY
****************************************************/
libname sasdata1 v6 "c:\temp\sasdata1";
proc datasets lib=WORK;
  delete HEARTRATE;
run;quit;

/****************************************************
 WORK WITH FORMATS
****************************************************/
libname sasdata2 v9 "c:\documents and settings\cscar\desktop\sasdata2";
libname library v6 "c:\documents and settings\cscar\desktop\sasdata1";
options FMTSEARCH=(WORK LIBRARY sasdata2);
options nofmterr;

proc format lib=sasdata2;
  value ranfmt 1="Ran" 2="Didn't Run";
  value sexfmt 1="Male" 2="Female";
run;

proc datasets lib=sasdata2;
  modify heartrate;
  format ran ranfmt. sex sexfmt.;
run;quit;

proc freq data=sasdata2.heartrate;
  tables ran sex;
run;

proc format lib=sasdata1 fmtlib;
run;
proc format lib=sasdata2 fmtlib;
run;

proc format lib=sasdata1 cntlout=formatdata;
run;
proc print data=formatdata;
run;

proc contents data=sasdata2.heartrate;
 run;




