/************************************************                                                                                       
 THIS COMMAND FILE ILLUSTRATES SEVERAL EXAMPLES                                                                                         
 OF HOW SAS DATA SETS CAN BE CREATED USING                                                                                              
 INPUT, SET, MERGE OR UPDATE STATEMENTS                                                                                                 
                                                                                                                                        
 FILENAME: DATASTEP.SAS                                                                                                                 
*************************************************/                                                                                      
                                                                                                                                        
/*Creating a SAS data set with an Input Statement*/                                                                                                   
data bp;                                                                                                                                
        infile "bp.dat" lrecl=300;                                                                                                                
        input  id sex $ age height weight
        sbp dbp;                                                                                      
    wtkg = weight * .455;                                                                                                               
    htcm = height * 2.54;                                                                                                               
    bmi  = wtkg / ((htcm/100)**2 ); 
    format bmi 10.2; 
	error=_error_;
	obsnum = _n_;
    drop wtkg htcm;                                                                                                                     
run;                                                                                                                                    
proc print;                                                                                                                             
 title "BP Data Set: Created Using INPUT";                                                                                              
run;                                                                                                                                    
                                                                                                                                        
/*Creating a SAS data set with a Set Statement*/                                                                                                             
                                                                                                                                        
data newbp;                                                                                                                             
  set bp;                                                                                                                               
          
  x=1; 
  if age < 30 then agegrp=1;                                                                                              
  if age >= 30 and age < 40 then agegrp=2;                                                                                              
  if age >= 40 and age < 50 then agegrp=3;                                                                                              
  if age >=50 then agegrp=4;                                                                                                            
  if age = . then agegrp=.;


 
  if bmi > 25 then hibmi=1;                                                                                                             
  else if 0 <=bmi <=25 then hibmi=0;                                                                                                    
run;                                                                                                                                    
                                                                                                                                        
proc print;                                                                                                                             
  title "NEWBP Data Set: Created Using SET";                                                                                            
run;                                                                                                                                    
                                                                                                                                        
/*Creating a SAS data set with a Merge Statement*/                                                                                              
data labvals;                                                                                                                           
  infile "labvalues.dat";                                                                                                               
  input id hrtrate cardiac hemo;                                                                                                        
run;                                                                                                                                    
proc sort data=newbp;                                                                                                                   
  by id;                                                                                                                                
run; 
proc contents data=newbp;
run;
 
proc sort data=labvals;                                                                                                                 
  by id;                                                                                                                                
run;                                                                                                                                    
data bplab;                                                                                                                             
  merge newbp labvals;                                                                                                                  
  by id;                                                                                                                                
run;                                                                                                                                    
proc print data=bplab;                                                                                                                  
  title "BPLAB Data Set: Created Using MERGE";                                                                                          
run;                                                                                                                                    
                                                                                                                                        
/*Updating values in a SAS data set with an Update Statement*/                                                                                                          
                                                                                                                                        
data transact;                                                                                                                          
  input id hrtrate hemo;                                                                                                                
  cards;                                                                                                                                
  1 135 12.1                                                                                                                            
  4  .  14.0                                                                                                                            
  ;                                                                                                                                     
data bplab_up;                                                                                                                          
 update bplab transact;                                                                                                                 
 by id;                                                                                                                                 
run;                                                                                                                                    
proc print data=bplab_up;                                                                                                               
  title "BBLAB_UP Data Set: Created Using UPDATE";                                                                                      
run;                                                                                                                                    
 
/*Using a Modify Statement to Modify a Data Set*/                                                                                                          
data bp;
  modify bp;
  age = age + 5;
run;
proc print data=bp;
  title "Modified BP data set";
run;

 
/*A commonly encountered data step problem
  Note: this overwrites the data set, bplab_up 
  and creates a data set with zero observations!*/                                                                                            
                                                                                                                                        
data bplab_up;                                                                                                                          
run;
