/********************************************
 THIS COMMAND FILE SHOWS EXAMPLES OF USING
 SIMPLE DESCRIPTIVE STATISTICS IN SAS.

 FILENAME:  DESCRIPT.SAS
*********************************************/
/*Specify generic output using Options Formchar= */
options formchar="|----|+|---+=|-/\<>*";
title;

options nodate pageno=1;
title;

data pulse;
   infile "pulse.dat";
   input pulse1 pulse2 ran smokes sex height weight activity;
run;


/*PROC PRINT - DIFFERENT OPTIONS*/

proc print;
run;

proc print data=pulse;
run;
proc print data=pulse(obs=6);
run;

proc print data=pulse(firstobs=82 obs=85);
run;

proc print data=pulse;
  var ran height pulse1;
run;

proc print data=pulse;
  var sex -- activity;
run;

proc print data=pulse label noobs;
  var sex -- activity;
run;

/*PROC CONTENTS*/

proc contents data=pulse;
run;

proc contents data=pulse varnum;
run;


/*PROC MEANS*/

proc means;
run;

proc means data = pulse;
  var height weight pulse1;
run;

proc means data = pulse;
  var ran -- activity;
  run;

proc means data = pulse;
    class ran;
run;

proc means data = pulse n mean min max;
    class ran activity;
run;

proc means data = pulse n mean min max skewness kurtosis;
  var pulse1 pulse2;
run;

/*95% Confidence Interval for Means*/
proc means data = pulse n mean clm;
  var pulse1 pulse2;
run;

proc means data = pulse n mean clm alpha = .01;
  var pulse1 pulse2;
run;

/*PROC FREQ*/

/*Oneway frequency tables*/
proc freq data = pulse;
   tables ran activity smokes;
run;

/*Twoway frequency table*/
proc freq data = pulse;
   tables sex * activity;
run;

proc freq data = pulse;
   tables sex * activity / norow nocol nopercent;
 run;

/*Threeway frequency table--stratified by RAN*/
proc freq data = pulse;
   tables ran* sex * activity / chisq ;
run;

/*PROC BOXPLOT*/

proc sort data = pulse;
  by sex;
run;
proc boxplot data = pulse;
  plot weight * sex ;
run;

proc boxplot data = pulse;
  plot weight * sex /boxstyle=schematic;
run;

/*PROC CHART*/

/*Vertical Bar charts*/
proc chart data = pulse;
   vbar weight;
run;

/*Bar chart for a categorical (discrete) variable*/
proc chart data = pulse;
   vbar activity / discrete;
run;

proc chart data = pulse;
   vbar weight / midpoints =  100 120 140 160 180 200 220  ;
run;

proc chart data = pulse;
   vbar weight / midpoints= 100 to 220 by 20;
run;

/*Horizontal Bar charts*/
proc chart data = pulse;
   hbar height ;
run;

proc chart data = pulse;
   hbar height / nostat;
run;

/*PROC UNIVARIATE*/

proc univariate data = pulse;
   var pulse1 ;
run;

proc univariate data = pulse;
   var pulse2;
   id ran;
run;

proc univariate data = pulse plot;
   histogram;
   qqplot / normal(mu=est sigma=est);
   var pulse1;
run;

proc univariate data = pulse plot normal;
   var pulse1;
run;

proc univariate data=pulse;
  class ran;
  var pulse2;
  histogram;
run;


/*PROC GPLOT*/

/*Simple scatter plot*/
goptions reset=all;
goptions device=win target=winprtm;

proc gplot data = pulse;
   plot pulse2 * pulse1;
run; 

/*Fit a linear regression and display the line*/
goptions reset=all;
goptions device=win target=winprtm;
symbol1 value=dot color=black interpol=rl line=1;

proc gplot data = pulse;
   plot pulse2*pulse1;
run; quit;

/*Different symbols for groups of cases*/
goptions reset=all;
goptions device=win target=winprtm;

proc gplot data = pulse;
   plot pulse2*pulse1 = ran;
run; quit;

/*Regression Lines for different groups of cases*/
goptions reset=all;
goptions device=win target=winprtm;
symbol1 color=black value=star interpol=rl line=1;
symbol2 color=black value=dot interpol=rl line=2;

proc gplot data = pulse;
   plot pulse2*pulse1 = ran;
run; quit;
