/************************************************
 THIS COMMAND FILE ILLUSTRATES THE USE OF DO
 STATEMENTS IN THE DATA STEP.

 FILENAME: DOLOOP.SAS
*************************************************/
title;
options nodate pageno=1;

/***************SIMPLE DO STATEMENTS**************/
data owen;
  infile "owen.dat";
  input fam_num childnum age sex race w_rank income_c height weight 
  hemo vit_c vit_a head_cir fatfold b_weight mot_age b_order 
  m_height f_height ;

  /*SET UP MISSING VALUE CODES*/

  if vit_a    = 99  then vit_a    = .;
  if head_cir = 99  then head_cir = .;
  if fatfold  = 99  then fatfold  = .;
  if mot_age  = 99  then mot_age  = .;
  if b_order  = 99  then b_order  = .;
 
  if b_weight = 999 then b_weight = .;
  if m_height = 999 then m_height = .;
  if f_height = 999 then f_height = .;

  /*USE DO GROUP, SO AGEGRP IS ONLY CREATED 
    FOR THOSE WITH MOT_AGE NOT= MISSING*/

  if mot_age not=. then do;
     if mot_age < 20 then agegrp = 1;
     if mot_age  >=   20 and mot_age  < 25 then agegrp = 2;
     if mot_age  >=   25 and mot_age  < 30 then agegrp = 3;
     if mot_age  >=   30 and mot_age  < 35 then agegrp = 4;
     if mot_age  >=   35 and mot_age  < 40 then agegrp = 5;
     if mot_age  >=   40 then agegrp  = 6;
  end;

  /*USE DO GROUP TO CREATE DUMMY VARIABLE FOR 
    B_WEIGHT < 2500 GMS ONLY IF B_WEIGHT NOT= MISSING*/

  b_weight = b_weight*10;
  if b_weight not=. then do;  
     lowbwt = (b_weight<2500);
  end;
run;

proc means;
run;

/******************NESTED DO LOOPS***********************/

data owen2;
  set owen;
  
  if sex=1 then do;
     if fatfold > 8 then do;
	    hifatfld  = 1;
        put "Fatfold > 8 for Male: " fam_num= childnum= sex= fatfold=;
	 end;
	 if 0 <= fatfold <= 8 then hifatfld  = 0;
  end;

  if sex=2 then do;
     if fatfold > 10 then do;
	    hifatfld  = 1;
        put "Fatfold > 10 for Female: " fam_num= childnum= sex= fatfold=;
	 end;
	 if 0 <= fatfold <= 10 then hifatfld  = 0;
  end;
run;

/**************ITERATIVE DO STATEMENTS*****************/

/**************USING A DO LOOP TO SET UP A DATA SET*****************/

data testdata;
  do x = 11 to 15;
  output;
  end;
run;
proc print;
run;

data testdata2;
 do trial = 1 to 3;
    do conc = 1 to 4;
    response = ranuni(24)*10;
	output;
	end;
 end;
run;
proc print;
run;

/**************USING A DO LOOP WITH DATE VALUES*****************/

data January;
  do date = "01JAN1990"D to "31JAN1990"D;
  format date date9.;
  output;
  end;
run;
proc print data=January;
run;


/**************USING A DO LOOP WITH CHARACTER VARIABLES 
               TO SET UP A DATA SET*****************/

data sample;
    length Season Region $12.;
    do Season="Spring","Summer", "Fall", "Winter";
         do Region ="North", "East", "South", "Central", "West";
              sales=ceil(ranuni(5527)*100000);
			  format sales dollar10.;
	          output;
         end;
    end;
run;
proc print data=sample;
run;


/**************UNCLOSED DO LOOP ERROR*****************/

data testdata3;
 do trial = 1 to 3;
    do conc = 1 to 4;
    response = ranuni(24)*10;
	output;
 end;
run;
proc print data=testdata3;
run;

