/*More Complex Macro Example*/

libname sasdata2 "c:\documents and settings\kathy\desktop\sasdata2";
ods trace on;
proc freq data=sasdata2.tecumseh;
  tables cig1*cig2 /agree norow nocol;
  tables cig1*cig3 /agree norow nocol;
  tables cig2*cig3 / agree norow nocol;
  test kappa;
run;         
ods trace off;

/*Now, output the data sets for the simple
  kappa tests*/

ods output  freq.table1.simplekappatest = sktest1
            freq.table2.simplekappatest = sktest2
            freq.table3.simplekappatest = sktest3;
 
proc freq data=sasdata2.tecumseh;
  tables cig1*cig2 /agree norow nocol;
  tables cig1*cig3 /agree norow nocol;
  tables cig2*cig3 / agree norow nocol;
  test kappa;
run;         

/*Append the data sets to get all kappa
  statistics into one data set*/

data testkappa;
   set sktest1;
run;
proc append base=testkappa data=sktest2;
run;
proc append base=testkappa data=sktest3;
run;
proc print data=testkappa;
run;

/*Now, calculate the p-value for each
  kappa test and put them all into one
  simple data set*/

data testkappa2;
  set testkappa;
  if name1 = "Z_KAPPA";
  drop cvalue1 label1;
 
  pvalue =2*( 1-(probt(abs(nvalue1),1000)));
  if pvalue < .00000001 then p = "<.0000001";
  if pvalue >=.00000001 then p = input(pvalue,$char15.);
  rename nvalue1 = zscore;

  format pvalue 15.14;
run;

proc print data=testkappa2;
run;


/*****************************************
 Now, set up the macros
******************************************/
options mprint symbolgen nomlogic;

/********************************************
 First, set up a macro to clear the ods data 
 sets, otherwise they will not be created if
 they already exist
*********************************************/

%macro cleardata(n);
proc datasets lib=work;
    %do t = 1 %to &n;
       delete sktest&t;
    %end;
run; quit;
%mend cleardata;

/******************************************
 Create a macro to pull off the kappa
 test statistics from the output, and 
 calculate the p-value for kappa 
 for each table
*******************************************/

%macro kappastats(n);
%do t = 1 % to &n;
  ods output freq.table&t..simplekappatest = sktest&t;
%end;

proc freq data=sasdata2.tecumseh;
  tables cig1*cig2 /agree norow nocol;
  tables cig1*cig3 /agree norow nocol;
  tables cig2*cig3 / agree norow nocol;
  test kappa;
run;     

%mend kappastats;

%macro calcz(n);
 
%do t = 1 % to &n;
   %if %eval(&t) = 1 %then %do;
      data testkappa;
       set sktest&t;
      run;
   %end;
   %else %if %eval(&t) > 1 %then %do;
     proc append base=testkappa data=sktest&t;
     run;
   %end;
%end;

data testkappa2;
  set testkappa;
  if name1 = "Z_KAPPA";
  drop cvalue1 label1;
 

  pvalue =2*( 1-(probt(abs(nvalue1),1000)));
  if pvalue < .00001 then p = "<.00001";
  if pvalue >=.00001 then p = input(pvalue,$char15.);
  rename nvalue1 = zscore;

  format pvalue 15.14;
run;
title "Printout of Kappa Test Stats for Each Table";
proc print data=testkappa2;
run;

%mend calcz;

%cleardata(3)
%kappastats(3)
%calcz(3)

