/************************************************
 THIS COMMAND FILE ILLUSTRATES HOW TO REARRANGE
 DATA FROM "LONG" FORMAT TO "WIDE" FORMAT.

 FILENAME: LONG2WIDE.SAS
*************************************************/
title;
options pageno=1 nodate;

/************************************
 The original Data in Wide Format
*************************************/

data PCALong;
 input id date :mmddyy10. PCA;
 format date mmddyy10.;
 cards;
 1 10/14/2003 124
 1 11/22/2003 145
 1 12/21/2003 152
 1 01/12/2004 111
 1 02/15/2004 127
 2 3/13/2004 101
 2 5/16/2004 125
 3 3/4/2004 115
 ;

title "PCALong Data";
proc print data=PCALong;
run;

proc sort data=PCALong;
  by id date;
run;

data PCAWide;

   array PcaVal(5) pca1 pca2 pca3 pca4 pca5;
   array dtvar(5) date1 date2 date3 date4 date5;

   format date1-date5 mmddyy10.;
   do i= 1 to 5;
     set PCAlong;
	   by id;
	   PcaVal(i) = pca;
	   dtvar(i) = date;
	 if last.id then return;
   end;
   drop date pca  i;
run;

proc print data=PCAwide;
run;

data PCAWide2;
  retain ID Date1 PCA1 Date2 pca2 date3 pca3 date4 pca4 date5 pca5;
  set PCAWide;
run;

title "Rearranged variables";
proc print data=pcawide2;
run;

/*ANOTHER EXAMPLE REARRANGING BOTH CHARACTER AND NUMERICI VARIABLES*/

/*READ IN ORIGINAL DATA IN LONG FORMAT*/

data fiber;
input Cracker $ Diet Subject Calories Bloat $ Bloatscor;
cards;
control 1       3       1772.84 none 0
bran    4       3       1752.63 low  1
combo   3       9       2121.97 med  2
gum     2       4       2558.61 high 3
gum     2       1       2026.91 med  2
bran    4       1       2047.42 low  1
combo   3       1       2254.75 low  1
control 1       1       2353.21 med  2
combo   3       2       2153.36 none 0
gum     2       2       2331.19 none 0
bran    4       2       2547.77 none 0
control 1       2       2591.12 none 0
gum     2       3       2012.36 low  1
combo   3       3       1956.18 low  1
combo   3       4       2025.97 none 0
bran    4       4       1669.12 none 0 
control 1       4       2452.73 none 0
bran    4       5       2207.37 low  1
gum     2       5       1944.48 med  2
control 1       5       1927.68 low  1
combo   3       5       2190.1  high 3
control 1       6       1635.28 none 0
combo   3       6       1693.35 low  1
bran    4       6       1707.34 low  1
gum     2       6       1871.95 high 3
gum     2       7       2245.03 none 0
combo   3       7       2436.79 low  1
control 1       7       2667.14 low  1
bran    4       7       2766.86 none 0
bran    4       8       2279.82 none 0
combo   3       8       1844.77 high 3
gum     2       8       2002.73 high 3
control 1       8       2220.22 med  2
control 1       9       1888.29 low  1
gum     2       9       1804.27 high 3
bran    4       9       2293.27 med  2
bran    4       10      2357.4  none 0
control 1       10      2359.9  none 0
combo   3       10      2292.46 low  1
gum     2       10      2433.46 high 3
gum     2       11      1681.86 low  1
control 1       11      1902.75 none 0
bran    4       11      2003.16 none 0
combo   3       11      2137.12 med  2
combo   3       12      2203.07 med  2
control 1       12      2125.39 low  1
gum     2       12      2166.77 med  2
bran    4       12      2287.52 none 0
;
proc print data=fiber;
title "Original Diet Data";
run;


/*REARRANGE DATA INTO WIDE FORMAT*/

proc sort data=fiber;
  by subject diet;
run;

data alldiet(keep=subject  control_bloat--bran_bloat control_cal -- bran_cal);   
   array bl (4) $ control_bloat gum_bloat combo_bloat bran_bloat; 
   array cal(4)   control_cal gum_cal combo_cal bran_cal;   
   do diet=1 to 4;
     set fiber;
	 by subject;	  
       bl(diet)  = bloat;
	   cal(diet) = calories;
	 if last.subject then return;
   end; 
run;

proc print data=alldiet;
 title "Rearranged Diet Data";
run;


