/****************************************************
 This command file reads in raw data from a file,
 generates random samples from it, and writes
 them out to data sets

 Filename: sample_data_macro.sas
******************************************************/

proc format;
     value genfmt    1="male"
                     2="female";
     value racefmt   1="black"
                     2="white";
     value stresfmt  1="high"
                     2="low";
run;

data project;
  infile "epid.dat";
  input id 1-6
        gender 7-8
        race 9-10
        stress 11-12
        sbp 13-16
        dbp 17-20
        age 21-23
        height 24-26
        weight 27-30
        pctovwt 31-35
        ;
  random=ranuni(1998);
run;

proc sort data=project out=test;
   by random;
run;

proc means data=test;
   title "checking the original reading of the data";
run;

proc freq data=test;
   tables gender race stress;
   format race racefmt. gender genfmt. stress stresfmt.; 
   title "checking values of the categorical variables";
run;

options  mprint macrogen;
%macro sample;

data names;
  infile "names.dat";
  length lname $14;
  input lname $ ;
  ; 

call symput("name"||left(_n_),trim(lname));
run;

%do i=1 %to 4;

data sample&i;
   retain k 800 n;
   drop n k;
   if _n_=1 then n=numobs;
    
   set test point=_n_ nobs=numobs;
   if ranuni(&i) <k/n then do;
    output;
    k=k-1;
    end;
   n=n-1;
   if n=0 or k=0 or _n_=numobs then stop;
run;

proc means data=sample&i;
  title "Sample Data Set for &name&i";
run;


filename out&i "&name&i...dat";

data _null_;
   set sample&i;
   file out&i;
   put id 1-6
       gender 7-8
       race 9-10 
       stress 11-12
       sbp 13-16
       dbp 17-20
       age 21-23
       height 24-26
       weight 27-30
       pctovwt 31-35
        ;
run;
    %end;
%mend;
%sample;




