/***************************************
 THIS COMMAND FILE SHOWS HOW TO SELECT
 CASES THAT ARE PROCESSED FOR A PROCEDURE.

 FILENAME: SELECT.SAS
****************************************/

OPTIONS FORMCHAR="|----|+|---+=|-/\<>*";

/*SELECT CASES BASED ON VALUES OF A CHARACTER VARIABLE*/

data marflt;
      infile "marflt.dat";
      input flight $ 1-4 @4 fltdate mmddyy6. 
      dest $ 18-20 passngrs 34-36 
      freight 43-45 capacity 46-48;
      format fltdate mmddyy8.;
      pctfull=(passngrs/capacity)*100;
run; 
proc print data=marflt;
    where dest = "LAX";
    var flight dest passngrs;
    title "Flights to Los Angeles";
run;


/*SELECTING CASES THAT HAVE MISSING VALUES FOR CHARACTER VARIABLES*/

proc print data=marflt;
    where dest = " ";
    var flight dest passngrs;
    title "Missing Destination";
run;

/*SELECT CASES BASED ON VALUES OF A NUMERIC VARIABLE*/

proc print data=marflt;
    where pctfull < 30;
    var flight dest passngrs capacity pctfull;
    title "Flights Less than 30 Percent Full";
run;

/*USING WHERE ... BETWEEN*/

proc print data=marflt;
    where pctfull between 25 and 30;
    title "Flights Between 25 and 30 Percent Full";
run;

proc print data=marflt;
    where (pctfull between 25 and 30) and (dest="DFW") ;
    title "Flights to Dallas-Fort Worth Between 25 and 30 Percent Full";
run;

/*SELECTING CASES THAT HAVE MISSING VALUES FOR NUMERIC VARIABLES*/

proc print data=marflt;
    where passngrs = .;
    var flight dest passngrs;
    title "Missing Passengers";
run;

/*SELECTING CASES BASED ON DATES*/

proc print data=marflt;
    where fltdate = "07MAR90"D;
    title "Flights on March 7th, 1990"; 
run;

proc print data=marflt;
    where fltdate between "07MAR90"d and "09MAR90"d;
	title "Flights Between March 7th and March 9th, 1990";
run;

/*SELECTING CASES THAT HAVE MISSING VALUES FOR DATE VARIABLES*/

proc print data=marflt;
    where fltdate = .;
    var flight dest fltdate;
    title "Missing Date";
run;



