/**********************************************
 THIS COMMAND FILE CARRIES OUT SOME BASIC
 STATISTICAL TESTS ON THE AFIFI DATA SET.

FILENAME: STATISTICS.SAS
***********************************************/
OPTIONS FORMCHAR="|----|+|---+=|-/\<>*";
OPTIONS PAGENO=1;

TITLE1 "INTRO SAS WORKSHOP";
TITLE2 "AFIFI ANALYSIS";

LIBNAME SASDATA2 "c:\temp\sasdata2\";
LIBNAME LIBRARY "c:\temp\sasdata2\";

OPTIONS FMTSEARCH=(WORK SASDATA2);
OPTIONS PAGESIZE=54 LINESIZE=80;
OPTIONS _LAST_=SASDATA2.AFIFI PAGENO=1;

PROC MEANS;
  TITLE3 "DESCRIPTIVE STATISTICS";
RUN;
PROC FREQ;
    TABLES SEX SURVIVE SEX SHOKTYPE SHOCK ;
    TITLE3 "FREQUENCY TABLES FOR SELECTED VARIABLES" ; 
RUN;
PROC FREQ;
    TABLES SHOCK*SURVIVE/CHISQ EXPECTED RELRISK;
    TITLE3 "CROSS TABULATIONS FOR SURVIVAL AND SHOCK TYPE" ; 
RUN;
PROC UNIVARIATE PLOT;
    ID IDNUM;
    VAR SBP1 URINE1 ;
    HISTOGRAM;
    TITLE3 "STEM AND LEAF PLOTS, NORMAL P-P PLOTS" ; 
RUN;
PROC TTEST;
    CLASS SURVIVE ;
    VAR SBP1 HEART1 CARDIAC1 MAP1;
    TITLE3 "INDEPENDENT SAMPLES T-TEST FOR SELECTED VARIABLES";RUN;
PROC TTEST;
    PAIRED SBP2*SBP1;
    TITLE3 "PAIRED T-TEST FOR SBP1 VS. SBP2";
FOOTNOTE "T-TEST IS FOR NULL HYPOTHESIS THAT MEAN OF THE DIFFERENCES EQUALS ZERO"; RUN;
PROC SORT;
    BY SURVIVE ; 
RUN;
PROC TTEST;
    BY SURVIVE;
    PAIRED SBP2*SBP1;
    TITLE4 "SEPARATELY FOR THOSE WHO SURVIVED AND THOSE WHO DIED"; 
RUN;
PROC CORR NOMISS;
    VAR SBP2 CARDIAC1 HEART1 HGB1 MAP1 ;
    TITLE3 "CORRELATIONS" ;
    FOOTNOTE ;
RUN;
PROC REG DATA=SASDATA2.AFIFI;
    ID IDNUM;
    MODEL SBP2= CARDIAC1 HEART1 HGB1 URINE1 MAP1 / R COLLIN DW STB TOL VIF;
    PLOT (RESIDUAL.) * (PREDICTED. CARDIAC1 HEART1 HGB1 )
    /SYMBOL="*" HPLOTS=2 VPLOTS=2;
    OUTPUT OUT=REGDAT P=PREDICT R=RESID;
    TITLE3 "REGRESSION ANALYSIS WITH DIAGNOSTIC PLOTS";
    TITLE4 "AND ANALYSIS OF RESIDUALS"; 
RUN;
PROC UNIVARIATE PLOT NORMAL;
    ID IDNUM;
    VAR RESID;
    HISTOGRAM;
    QQPLOT / NORMAL(MU=EST SIGMA=EST);
    TITLE3 "CHECKING FOR NORMALITY OF RESIDUALS"; RUN;
PROC GLM;
    CLASS SHOKTYPE;
    MODEL SBP1=SHOKTYPE;
    MEANS SHOKTYPE/ TUKEY NOSORT;
    TITLE3 "ONEWAY ANALYSIS OF VARIANCE";
    TITLE4 "WITH TUKEY MULTIPLE COMPARISON TECHNIQUE";RUN; 
PROC LOGISTIC DESCENDING;
   CLASS SHOKTYPE / PARAM=REF REF=FIRST;
   MODEL DIED = SHOKTYPE SBP1 CARDIAC1/ RL RSQUARE LACKFIT;
   UNITS SBP1=1 10 CARDIAC1=1;
   TITLE3 "LOGISTIC REGRESSION"; 
RUN;
