/************************************************
 THIS COMMAND FILE ILLUSTRATES HOW TO REARRANGE
 A DATA SET FROM WIDE TO LONG FORMAT

 FILENAME: WIDE2LONG.SAS
*************************************************/
title;
options nodate pageno=1;

data wide;
  input id x1 y1 x2 y2 x3 y3;
  cards;
1 22 37 15 12 15 18
2 44 13 10 14 11 14
;
title "Wide Data Set";
proc print data=wide;
run;

data long(keep=id x y time);
  set wide;
  x=x1;
  y=y1;
  time=1;
  output;

  x=x2;
  y=y2;
  time=2;
  output;

  x=x3;
  y=y3;
  time=3;
  output;
run;

title "Long Data Set";
proc print data=long;
run;

/*A More Complex Example*/

data weather1;
  input city $ &12. HighThu  LowThu HighFri LowFri HighSat LowSat 
               HighSun  LowSun HighMon LowMon;
  cards;
Ann Arbor     52 31 55 35 50 33 55 39 60 39
Grand Rapids  50 32 51 36 49 37 53 38 59 38
Grand Marais  39 28 43 29 44 28 49 32 44 32
;

proc print data=weather1;
 title "Original Weather Data Set";
run;

data weather2 (keep=city date high low day);
  set weather1;
  format date mmddyy10.;

  high = HighThu;
  low  = LowThu;
  day  = "Thursday";
  date = "25APR02"D;
  output;

  high = HighFri;
  low  = LowFri;
  day  = "Friday";
  date = "26APR02"D;
  output;

  high = HighSat;
  low  = LowSat;
  day  = "Saturday";
  date = "27APR02"D;
  output;

  high = HighSun;
  low  = LowSun;
  day  = "Sunday";
  date = "28APR02"D;
  output;

  high = HighMon;
  low  = LowMon;
  day  = "Monday";
  date = "29APR02"D;
  output;
run;

proc print data=weather2;
 title "Rearranged Weather Data Set";
run;

/*USE ARRAYS TO REARRANGE THE DATA*/

data weather3(keep=city date high low );
   set weather1;

   array hi(5) highthu highfri highsat highsun highmon;
   array lo(5)  lowthu  lowfri  lowsat  lowsun  lowmon;

   do i = 1 to 5;
     high = hi(i);
	 low  = lo(i);
	 date = "25APR02"D+(i-1);
	 format date mmddyy8.;
     output;
   end;
run;

proc print data=weather3;
  title "Weather3 Data Set";
run;
    
